"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = __importDefault(require("node-fetch"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const cheerio_1 = __importDefault(require("cheerio"));
const util_1 = require("./util");
const filenamify_1 = __importDefault(require("filenamify"));
const sitdown_1 = require("sitdown");
const headers_1 = require("./headers");
const sitdown = new sitdown_1.Sitdown({
    keepFilter: ["style"],
    codeBlockStyle: "fenced",
    bulletListMarker: "-",
    hr: "---",
});
const generateByPage = (params) => __awaiter(this, void 0, void 0, function* () {
    //
    let writeStream = null;
    let { output, time, id, csdn } = params;
    output = path_1.default.resolve(output);
    if (!util_1.fsExistsSync(output)) {
        console.log("输出目录不存在，正在创建...");
        fs_1.default.mkdirSync(output);
    }
    try {
        const html = yield node_fetch_1.default(`${csdn}/article/details/${id}`, {
            headers: headers_1.headers,
        }).then((res) => res.text());
        let tags = []; //标签...爬虫获取不到标签
        let categories = []; //分类
        const $ = cheerio_1.default.load(html, {
            decodeEntities: true,
        });
        const title = $(".title-article").text();
        const x = $("#content_views").html();
        // csdn一个诡异的注释<!-- flowchart 箭头图标 勿删 -->
        const commentReg = /<!-- flowchart 箭头图标 勿删 -->/;
        if (!x) {
            return;
        }
        const markdown = sitdown.HTMLToMD(x).replace(commentReg, "");
        categories.push($(".tag-link").text().replace(/\s/g, ""));
        writeStream = fs_1.default.createWriteStream(path_1.default.join(output, `./${filenamify_1.default(title)}.md`), "utf8");
        console.log("生成", title);
        writeStream.write("---\n");
        writeStream.write(`title: ${title}\n`);
        writeStream.write(`date: ${time}\n`);
        writeStream.write(`tags: ${tags.join(" ")}\n`);
        writeStream.write(`categories: ${categories.join(" ")}\n`);
        writeStream.write("---\n\n");
        writeStream.write("<!--more-->\n\n");
        writeStream.write(markdown || "");
        writeStream.end("");
    }
    catch (e) {
        console.log(`出错: ${id}`, e);
    }
    finally {
        if (writeStream) {
            writeStream.close();
        }
    }
});
exports.default = generateByPage;
//# sourceMappingURL=generateByPage.js.map